@@ -2,7 +2,7 @@
 use crate::client::json;
 use crate::esc;
 use crate::server::RequestExt;
-use crate::utils::{cookie, error, format_num, format_url, param, rewrite_urls, template, time, val, Author, Comment, Flags, Flair, FlairPart, Media, Post, Preferences};
+use crate::utils::{error, format_num, format_url, param, rewrite_urls, setting, template, time, val, Author, Comment, Flags, Flair, FlairPart, Media, Post, Preferences};
 use hyper::{Body, Request, Response};
 
 use async_recursion::async_recursion;
@@ -28,7 +28,7 @@ pub async fn item(req: Request<Body>) -> Result<Response<Body>, String> {
 	let mut sort: String = param(&path, "sort");
 
 	// Grab default comment sort method from Cookies
-	let default_sort = cookie(&req, "comment_sort");
+	let default_sort = setting(&req, "comment_sort");
 
 	// If there's no sort query but there's a default sort, set sort to default_sort
 	if sort.is_empty() && !default_sort.is_empty() {
