@@ -1,6 +1,6 @@
 // CRATES
 use crate::esc;
-use crate::utils::{catch_random, cookie, error, format_num, format_url, param, redirect, rewrite_urls, template, val, Post, Preferences, Subreddit};
+use crate::utils::{catch_random, error, format_num, format_url, param, redirect, rewrite_urls, setting, template, val, Post, Preferences, Subreddit};
 use crate::{client::json, server::ResponseExt, RequestExt};
 use askama::Template;
 use cookie::Cookie;
@@ -31,8 +31,8 @@ struct WikiTemplate {
 // SERVICES
 pub async fn community(req: Request<Body>) -> Result<Response<Body>, String> {
 	// Build Reddit API path
-	let subscribed = cookie(&req, "subscriptions");
-	let front_page = cookie(&req, "front_page");
+	let subscribed = setting(&req, "subscriptions");
+	let front_page = setting(&req, "front_page");
 	let post_sort = req.cookie("post_sort").map_or_else(|| "hot".to_string(), |c| c.value().to_string());
 	let sort = req.param("sort").unwrap_or_else(|| req.param("id").unwrap_or(post_sort));
 
@@ -114,16 +114,19 @@ pub async fn subscriptions(req: Request<Body>) -> Result<Response<Body>, String>
 	let mut sub_list = Preferences::new(req).subscriptions;
 
 	// Retrieve list of posts for these subreddits to extract display names
-	let display = json(format!("/r/{}/hot.json?raw_json=1", sub)).await?;
-	let display_lookup: Vec<(String, &str)> = display["data"]["children"]
+	let posts = json(format!("/r/{}/hot.json?raw_json=1", sub)).await?;
+	let display_lookup: Vec<(String, &str)> = posts["data"]["children"]
 		.as_array()
-		.unwrap()
-		.iter()
-		.map(|post| {
-			let display_name = post["data"]["subreddit"].as_str().unwrap();
-			(display_name.to_lowercase(), display_name)
+		.map(|list| {
+			list
+				.iter()
+				.map(|post| {
+					let display_name = post["data"]["subreddit"].as_str().unwrap_or_default();
+					(display_name.to_lowercase(), display_name)
+				})
+				.collect::<Vec<_>>()
 		})
-		.collect();
+		.unwrap_or_default();
 
 	// Find each subreddit name (separated by '+') in sub parameter
 	for part in sub.split('+') {
@@ -243,17 +246,22 @@ async fn moderators_list(sub: &str) -> Result<Vec<String>, String> {
 
 	// Retrieve response
 	let response = json(path).await?["data"]["children"].clone();
-	Ok(if let Some(response) = response.as_array() {
+	Ok(
 		// Traverse json tree and format into list of strings
 		response
+			.as_array()
+			.unwrap_or(&Vec::new())
 			.iter()
-			.map(|m| m["name"].as_str().unwrap_or(""))
-			.filter(|m| !m.is_empty())
-			.map(std::string::ToString::to_string)
-			.collect::<Vec<_>>()
-	} else {
-		vec![]
-	})
+			.filter_map(|moderator| {
+				let name = moderator["name"].as_str().unwrap_or_default();
+				if name.is_empty() {
+					None
+				} else {
+					Some(name.to_string())
+				}
+			})
+			.collect::<Vec<_>>(),
+	)
 }
 
 // SUBREDDIT
@@ -270,7 +278,7 @@ async fn subreddit(sub: &str) -> Result<Subreddit, String> {
 			let active: i64 = res["data"]["accounts_active"].as_u64().unwrap_or_default() as i64;
 
 			// Fetch subreddit icon either from the community_icon or icon_img value
-			let community_icon: &str = res["data"]["community_icon"].as_str().unwrap();
+			let community_icon: &str = res["data"]["community_icon"].as_str().unwrap_or_default();
 			let icon = if community_icon.is_empty() { val(&res, "icon_img") } else { community_icon.to_string() };
 
 			let sub = Subreddit {
